@@ -1,3 +1,6 @@
+import re
+
+from datetime import datetime
 from functools import wraps
 from flask import request, jsonify, make_response
 from json import dumps
@@ -10,8 +13,15 @@ from mongoengine.errors import ValidationError
 
 from .exceptions import InvalidPayloadSupplied, BadRequest, Forbidden
 
+# Constant fields
+
 API_PREFIX = '/api'
 
+class QueryArgs:
+    DAY = 'day'
+    ORDER_BY = 'order_by'
+    DESC = 'desc'
+
 # Pagination
 DEFAULT_PAGE_SIZE = 10
 
@@ -28,7 +38,7 @@ def create_module(app):
 
     create_api_v1(app, api)
 
-    # Using workaround from here to handle inerith exception handling from flask: https://github.com/flask-restful/flask-restful/issues/280#issuecomment-280648790
+    # Using workaround from here to handle inherit exception handling from flask: https://github.com/flask-restful/flask-restful/issues/280#issuecomment-280648790
     handle_exceptions = app.handle_exception
     handle_user_exception = app.handle_user_exception
     api.init_app(app)
@@ -66,6 +76,44 @@ def validate_payload(model_schema: ModelSchema, kwname='payload'):
 
     return decorate
 
+def parse_query_args(func):
+    query_args_reqparse = reqparse.RequestParser()
+    query_args_reqparse.add_argument(
+        QueryArgs.DAY,
+        type=str,
+        location=['args'],
+        required=False,
+        default=None
+    )
+    query_args_reqparse.add_argument(
+        QueryArgs.ORDER_BY,
+        type=str,
+        location=['args'],
+        required=False,
+        default=None
+    )
+    query_args_reqparse.add_argument(
+        QueryArgs.DESC,
+        type=bool,
+        location=['args'],
+        required=False,
+        default=False
+    )
+    @wraps(func)
+    def wrapper(*args, **kwargs):
+        query_args = query_args_reqparse.parse_args()
+
+        kwargs['query_args'] = {
+            QueryArgs.DAY: query_args[QueryArgs.DAY],
+            QueryArgs.ORDER_BY: query_args[QueryArgs.ORDER_BY],
+            QueryArgs.DESC: query_args[QueryArgs.DESC],
+
+        }
+
+        return func(*args, **kwargs)
+    return wrapper
+
+
 
 def get_payload(kwname='payload'):
     def decorate(func):
@@ -124,7 +172,7 @@ def paginated(func):
         if per_page <= 0:
             raise BadRequest('per_page argument must be greater than zero')
 
-        kwargs['req_args'] = {
+        kwargs['page_args'] = {
             'page': page,
             'per_page': per_page
         }
@@ -152,6 +200,7 @@ def _update_document(coll_class: mongo.Document.__class__, new_doc: mongo.Docume
     # Remove generated id and link new doc with current owner
     new_doc.id = None
     new_doc.owner = old_doc.owner
+    new_doc.insert_timestamp = old_doc.insert_timestamp
 
     if patch == True:
         return coll_class._get_collection().update(
@@ -173,3 +222,39 @@ def put_embedded_document(new_doc: mongo.EmbeddedDocument, old_doc: mongo.Embedd
 
 def patch_embedded_document(new_doc: mongo.EmbeddedDocument, old_doc: mongo.EmbeddedDocument):
     return _update_embedded_document(new_doc, old_doc, patch=True)
+
+
+def _build_query_by_params(base_query, query_args):
+    if QueryArgs.DAY in query_args and query_args[QueryArgs.DAY] is not None:
+        if bool(re.search('^[0-9]{4}-[0-1][0-9]-[0-3][0-9]$', query_args[QueryArgs.DAY])):
+            try:
+                searched_day = datetime.strptime(query_args[QueryArgs.DAY], '%Y-%m-%d')
+            except ValueError as ex:
+                raise BadRequest('invalid day parameter supplied: {}'.format(ex))
+        else:
+            raise BadRequest('invalid day format')
+        
+        base_query = base_query & Q(date=searched_day)
+    
+    return base_query
+
+def _apply_ordering(filtered_objects, query_args):
+    if(query_args[QueryArgs.ORDER_BY] != None and query_args[QueryArgs.ORDER_BY] != ''):
+        if(query_args[QueryArgs.DESC] == True):
+            filtered_objects = filtered_objects.order_by('-' + query_args[QueryArgs.ORDER_BY]) # descending "-"
+        else:
+            filtered_objects = filtered_objects.order_by('+' + query_args[QueryArgs.ORDER_BY]) # ascending "+"
+
+    return filtered_objects 
+
+def _apply_pagination(ordered_objects, page_args):
+    return ordered_objects.paginate(page=page_args['page'], per_page=page_args['per_page'])
+
+def search_on_model(coll_class: mongo.Document.__class__, base_query, query_args, page_args):
+    query_filter = _build_query_by_params(base_query, query_args)
+
+    filtered_objects = coll_class.objects(query_filter)
+    ordered_objects = _apply_ordering(filtered_objects, query_args)
+    paginated_objects = _apply_pagination(ordered_objects, page_args)
+
+    return paginated_objects
\ No newline at end of file
