@@ -11,12 +11,13 @@ class User(mongo.Document):
     password = mongo.BinaryField(required=True)
     email = mongo.StringField(unique=True, regex=USER_EMAIL_REGEX)
 
-    shoppindDay = mongo.ListField(
+    shoppingDay = mongo.ListField(
         mongo.IntField(min_value=1, max_value=7)
     )
 
     meta = {
-        'collection' : 'users'
+        'collection' : 'users',
+        'strict': False
     }
 
     def __repr__(self):
