@@ -7,19 +7,19 @@ from mongoengine.errors import NotUniqueError
 from mongoengine.fields import ObjectIdField
 from mongoengine.queryset.visitor import Q
 
-from .schemas import IngredientSchema, IngredientSchemaWithoutName
+from .schemas import IngredientSchema, PatchIngredientSchema, PutIngredientSchema
 from ...models import Ingredient, User, Recipe, ShoppingList
-from ... import validate_payload, get_payload, paginated, mongo, load_user_info, put_document, patch_document
+from ... import validate_payload, get_payload, paginated, parse_query_args, mongo, load_user_info, put_document, patch_document, search_on_model
 from ...exceptions import DuplicateEntry, BadRequest, Forbidden
 
 
 class IngredientsList(Resource):
     @jwt_required
+    @parse_query_args
     @paginated
     @load_user_info
-    def get(self, req_args, user_info: User):
-        return Ingredient.objects(owner=str(user_info.id)).paginate(
-            page=req_args['page'], per_page=req_args['per_page'])
+    def get(self, query_args, page_args, user_info: User):
+        return search_on_model(Ingredient, Q(owner=str(user_info.id)), query_args, page_args)
 
     @jwt_required
     @validate_payload(IngredientSchema(), 'ingredient')
@@ -62,7 +62,7 @@ class IngredientInstance(Resource):
             return "", 204
 
     @jwt_required
-    @validate_payload(IngredientSchema(), 'new_ingredient')
+    @validate_payload(PutIngredientSchema(), 'new_ingredient')
     @load_user_info
     def put(self, new_ingredient: Ingredient, user_info: User, ingredient_id=''):
         old_ingredient = Ingredient.objects(
@@ -78,7 +78,7 @@ class IngredientInstance(Resource):
         return old_ingredient, 200
 
     @jwt_required
-    @validate_payload(IngredientSchemaWithoutName(), 'new_ingredient')
+    @validate_payload(PatchIngredientSchema(), 'new_ingredient')
     @load_user_info
     def patch(self, new_ingredient, user_info: User, ingredient_id=''):
         old_ingredient = Ingredient.objects(
