@@ -7,9 +7,9 @@ from mongoengine.errors import NotUniqueError
 from mongoengine.fields import ObjectIdField, ObjectId
 from mongoengine.queryset.visitor import Q
 
-from .schemas import RecipeSchema, RecipeSchemaWithoutName, RecipeIngredientSchema, RecipeIngredientWithoutRequiredIngredientSchema
+from .schemas import RecipeSchema, PatchRecipeSchema, PutRecipeSchema, RecipeIngredientSchema, RecipeIngredientWithoutRequiredIngredientSchema
 from ...models import Recipe, User, RecipeIngredient
-from ... import validate_payload, paginated, mongo, put_document, patch_document, load_user_info, patch_embedded_document
+from ... import validate_payload, paginated, mongo, put_document, patch_document, load_user_info, patch_embedded_document, parse_query_args, search_on_model
 from ...exceptions import DuplicateEntry, BadRequest, Conflict, NotFound
 
 
@@ -25,13 +25,11 @@ def _dereference_ingredients(recipe: Recipe):
 
 class RecipeList(Resource):
     @jwt_required
+    @parse_query_args
     @paginated
     @load_user_info
-    def get(self, req_args, user_info: User):
-        page = Recipe.objects(owner=str(user_info.id)).paginate(
-            page=req_args['page'], per_page=req_args['per_page'])
-        #page.items = [_dereference_ingredients(item) for item in page.items]
-        return page
+    def get(self, query_args, page_args, user_info: User):
+        return search_on_model(Recipe, Q(owner=str(user_info.id)), query_args, page_args)
 
     @jwt_required
     @validate_payload(RecipeSchema(), 'recipe')
@@ -67,7 +65,7 @@ class RecipeInstance(Resource):
         return "", 204
 
     @jwt_required
-    @validate_payload(RecipeSchema(), 'new_recipe')
+    @validate_payload(PutRecipeSchema(), 'new_recipe')
     @load_user_info
     def put(self, new_recipe: Recipe, user_info: User, recipe_id=''):
         old_recipe = Recipe.objects(Q(id=recipe_id) & Q(owner=str(user_info.id))).get_or_404()
@@ -81,7 +79,7 @@ class RecipeInstance(Resource):
         return old_recipe, 200
 
     @jwt_required
-    @validate_payload(RecipeSchemaWithoutName(), 'new_recipe')
+    @validate_payload(PatchRecipeSchema(), 'new_recipe')
     @load_user_info
     def patch(self, new_recipe: Recipe, user_info: User, recipe_id=''):
         old_recipe = Recipe.objects(Q(id=recipe_id) & Q(owner=str(user_info.id))).get_or_404()
